# Accessibility Tools

This module is based on the a11Y module and designed to offer accessible tools 
for Drupal developers, helping improve usability for individuals relying on 
assistive technologies or alternative display methods. It currently provides a 
customizable block that includes:

- [Dyslexic font support](http://opendyslexic.org/)
- High contrast mode
- Inverted Colors mode
- Text scaling
- Keyboard navigation (Only D8/D9)

These features are implemented using advanced CSS techniques, and user preferences are retained via Drupal's built-in jQuery Cookie functionality.
To foster a deeper understanding of accessibility needs, the module also includes support for disability simulations. These can be enabled through the same block, provided the user has the appropriate permissions. *(Note: These simulations are intentionally designed to mimic accessibility challenges and should not be activated for regular site users.)* Currently supported simulations include:

- **Dyslexia**: Inspired by [Javascript that powers this demo](http://geon.github.io/programming/2016/03/03/dsxyliea), this feature randomly rearranges letters within words on your site to emulate the reading challenges faced by individuals with dyslexia.
- **Field Loss**: Based on [W3C guidelines for visual impairments](https://www.w3.org/TR/low-vision-needs/), this adds a CSS overlay that mimics peripheral and central vision loss. It retains full click and navigation functionality, allowing users to experience content as those with visual field loss might.
- **Colorblindness**: This uses CSS and SVG filters to simulate various color vision deficiencies, including **protanopia, deuteranopia, tritanopia**, and more, along with monochromatic conditions like **achromatopsia**.

Originally developed for Drupal 7 and later ported to support Drupal 8/9, the module has now been updated for Drupal 10/11. Enhancements include improved tabbed navigation, enabling users to traverse page elements seamlessly using the Tab key.

**Additional Accessibility Resources:**
- **[Speed Reader](https://www.drupal.org/project/speedreader)**: Helps isolate and display text in a manner that's easier to process for users with visual challenges.
- **[Accessibility Module](https://www.drupal.org/project/accessibility)**: Provides guidelines for content creators to ensure compliance with standards like Section 508 or WCAG 2.0 AA.
- **[Block ARIA Landmark Roles](https://www.drupal.org/project/block_aria_landmark_roles)**: Simplifies the assignment of ARIA landmark roles to blocks directly from the block interface.

Our goal is to make the web more accessible and intuitive for everyone. Contributions and suggestions are welcome, especially those aimed at improving theming, usability, and support for diverse accessibility tools.

## Table of contents

- Requirements
- Installation
- Configuration
- Maintainers

## Requirements

This module requires no modules outside of Drupal core.

## Installation

Install as you would normally install a contributed Drupal module. For further information, see [Installing Drupal Modules](https://www.drupal.org/docs/extending-drupal/installing-drupal-modules).

Once the installation is complete, the following features will be automatically enabled:
- Animation
- Contrast
- Dyslexic
- Invert
- Keyboard Navigation
- Text Size

You will then need to add an a11y block in the block layout section.

## Configuration
1. Go to Administration » Configuration » System » A11y
2. Edit an A11y entity to enable or disabled it.

## Maintainers
- Thomas Roger - [anzelkiel](https://www.drupal.org/u/anzelkiel)