/**
 * @file
 * Attaches next behavior for animation functionality.
 */

(function (Drupal, drupalSettings) {
  let init = false;

  Drupal.behaviors.a11y_animation = {
    attach() {
      const b = this;

      if (!init) {
        init = true;

        b.init();

        const input = document.querySelector('.a11y-animation-control');
        input.addEventListener('click', (e) => {
          b.dispatcher(e, b);
        });
      }
    },

    init() {
      const input = document.querySelector('.a11y-animation-control');
      const body = document.querySelector('body');

      if (Cookies.get('a11y_animation') === 'true') {
        body.classList.add('a11y-animation');
        input.classList.add('is-active');
      } else {
        body.classList.remove('a11y_animation');
        input.classList.remove('is-active');
      }
    },

    dispatcher(context, b) {
      const input = context.currentTarget;
      const body = document.querySelector('body');
      let value = null;

      if (input.classList.contains('is-active')) {
        input.classList.remove('is-active');
        body.classList.remove('a11y-animation');
        value = false;
      } else {
        input.classList.add('is-active');
        body.classList.add('a11y-animation');
        value = true;
      }

      Cookies.set('a11y_animation', value, { path: '/' });
    },
  };
})(Drupal, drupalSettings);
