/**
 * @file
 * Attaches next behavior for textsize functionality.
 */

(function (Drupal, drupalSettings) {
  let init = false;

  Drupal.behaviors.a11y_textsize = {
    attach(context, settings) {
      if (!init) {
        init = true;

        this.init();

        const inputs =
          document.querySelectorAll('.a11y-textsize-control') || [];
        inputs.forEach((input) => {
          input.addEventListener('click', (e) => {
            this.dispatcher(e);
          });
        });
      }
    },

    init() {
      const body = document.querySelector('body');
      const factor = Cookies.get('a11y_textsize');

      body.style.zoom = factor !== undefined ? factor : 1;
    },

    dispatcher(context) {
      const input = context.currentTarget;
      const body = document.querySelector('body');
      let factor = parseFloat(Cookies.get('a11y_textsize'));

      if (Number.isNaN(factor)) {
        factor = 1;
      }

      const action = this.getAttr(input);
      if (action === 'decrease') {
        factor -= 0.025;
      } else if (action === 'reset') {
        factor = 1;
      } else if (action === 'increase') {
        factor += 0.025;
      } else {
        factor = 1;
      }

      body.style.zoom = factor;

      Cookies.set('a11y_textsize', factor, { path: '/' });
    },

    getAttr(input) {
      return input.getAttribute('data-a11y-action');
    },
  };
})(Drupal, drupalSettings);
